@@ -593,7 +593,8 @@ jQuery.fn.extend({
             // Clock pointers contained
             $("span.content span.pointer", message_element).mouseenter(function(){
                 var $this_pointer = $(this),
-                    clock_pointer = jQuery.trim($this_pointer.text());
+                    clock_pointer = jQuery.trim($this_pointer.text()),
+                    _clock_pointer_match_count;
                 $this_pointer.addClass("highlighted");
                 
                 // Get related pointers in all messages and highlight them
@@ -604,6 +605,8 @@ jQuery.fn.extend({
                 
                 // Get related messages and highlight them
                 clock_name = "msgclock_"+clock_store.plainclock_to_cssname(clock_pointer);
+                _clock_pointer_match_count = 0;
+                if(DEBUG) console.info("Clock pointer hover for: %s", clock_name);
                 $("li."+clock_name, djangotribune_element).each(function(index) {
                     $(this).addClass("highlighted");
                     if(DEBUG) {
@@ -637,8 +640,14 @@ jQuery.fn.extend({
                         // Apply css position and show it
                         djangotribune_data.absolute_container.css(css_attrs).show()
                     }
+                    _clock_pointer_match_count += 1;
                     if(DEBUG) console.groupEnd();
                 });
+                // So there is no matched clock in the current history..
+                //if(DEBUG) console.info("Clock pointer matched: %s", _clock_pointer_match_count);
+                if(_clock_pointer_match_count == 0){
+                    if(DEBUG) console.warn("No matched clock %s in current history", clock_pointer);
+                }
             }).mouseleave(function(){
                 $(this).removeClass("highlighted");
                 // Get related pointers and un-highlight them
